@@ -89,6 +89,17 @@ func Test_RepoMetadata(t *testing.T) {
 			"pageInfo": { "hasNextPage": false }
 		} } } }
 		`))
+	http.Register(
+		httpmock.GraphQL(`query RepositoryProjectV2List\b`),
+		httpmock.StringResponse(`
+		{ "data": { "repository": { "projectsV2": {
+			"nodes": [
+				{ "title": "CleanupV2", "id": "CLEANUPV2ID" },
+				{ "title": "RoadmapV2", "id": "ROADMAPV2ID" }
+			],
+			"pageInfo": { "hasNextPage": false }
+		} } } }
+		`))
 	http.Register(
 		httpmock.GraphQL(`query OrganizationProjectList\b`),
 		httpmock.StringResponse(`
@@ -99,6 +110,16 @@ func Test_RepoMetadata(t *testing.T) {
 			"pageInfo": { "hasNextPage": false }
 		} } } }
 		`))
+	http.Register(
+		httpmock.GraphQL(`query OrganizationProjectV2List\b`),
+		httpmock.StringResponse(`
+		{ "data": { "organization": { "projectsV2": {
+			"nodes": [
+				{ "title": "TriageV2", "id": "TRIAGEV2ID" }
+			],
+			"pageInfo": { "hasNextPage": false }
+		} } } }
+		`))
 	http.Register(
 		httpmock.GraphQL(`query OrganizationTeamList\b`),
 		httpmock.StringResponse(`
@@ -110,6 +131,11 @@ func Test_RepoMetadata(t *testing.T) {
 			"pageInfo": { "hasNextPage": false }
 		} } } }
 		`))
+	http.Register(
+		httpmock.GraphQL(`query UserCurrent\b`),
+		httpmock.StringResponse(`
+		  { "data": { "viewer": { "login": "monalisa" } } }
+		`))
 
 	result, err := RepoMetadata(client, repo, input)
 	if err != nil {
@@ -144,13 +170,17 @@ func Test_RepoMetadata(t *testing.T) {
 	}
 
 	expectedProjectIDs := []string{"TRIAGEID", "ROADMAPID"}
-	projectIDs, err := result.ProjectsToIDs([]string{"triage", "roadmap"})
+	expectedProjectV2IDs := []string{"TRIAGEV2ID", "ROADMAPV2ID"}
+	projectIDs, projectV2IDs, err := result.ProjectsToIDs([]string{"triage", "roadmap", "triagev2", "roadmapv2"})
 	if err != nil {
 		t.Errorf("error resolving projects: %v", err)
 	}
 	if !sliceEqual(projectIDs, expectedProjectIDs) {
 		t.Errorf("expected projects %v, got %v", expectedProjectIDs, projectIDs)
 	}
+	if !sliceEqual(projectV2IDs, expectedProjectV2IDs) {
+		t.Errorf("expected projectsV2 %v, got %v", expectedProjectV2IDs, projectV2IDs)
+	}
 
 	expectedMilestoneID := "BIGONEID"
 	milestoneID, err := result.MilestoneToID("big one.oh")
@@ -160,18 +190,27 @@ func Test_RepoMetadata(t *testing.T) {
 	if milestoneID != expectedMilestoneID {
 		t.Errorf("expected milestone %v, got %v", expectedMilestoneID, milestoneID)
 	}
+
+	expectedCurrentLogin := "monalisa"
+	if result.CurrentLogin != expectedCurrentLogin {
+		t.Errorf("expected current user %v, got %v", expectedCurrentLogin, result.CurrentLogin)
+	}
 }
 
 func Test_ProjectsToPaths(t *testing.T) {
-	expectedProjectPaths := []string{"OWNER/REPO/PROJECT_NUMBER", "ORG/PROJECT_NUMBER"}
+	expectedProjectPaths := []string{"OWNER/REPO/PROJECT_NUMBER", "ORG/PROJECT_NUMBER", "OWNER/REPO/PROJECT_NUMBER_2"}
 	projects := []RepoProject{
 		{ID: "id1", Name: "My Project", ResourcePath: "/OWNER/REPO/projects/PROJECT_NUMBER"},
 		{ID: "id2", Name: "Org Project", ResourcePath: "/orgs/ORG/projects/PROJECT_NUMBER"},
 		{ID: "id3", Name: "Project", ResourcePath: "/orgs/ORG/projects/PROJECT_NUMBER_2"},
 	}
-	projectNames := []string{"My Project", "Org Project"}
+	projectsV2 := []RepoProjectV2{
+		{ID: "id4", Title: "My Project V2", ResourcePath: "/OWNER/REPO/projects/PROJECT_NUMBER_2"},
+		{ID: "id5", Title: "Org Project V2", ResourcePath: "/orgs/ORG/projects/PROJECT_NUMBER_3"},
+	}
+	projectNames := []string{"My Project", "Org Project", "My Project V2"}
 
-	projectPaths, err := ProjectsToPaths(projects, projectNames)
+	projectPaths, err := ProjectsToPaths(projects, projectsV2, projectNames)
 	if err != nil {
 		t.Errorf("error resolving projects: %v", err)
 	}
@@ -200,20 +239,41 @@ func Test_ProjectNamesToPaths(t *testing.T) {
 	http.Register(
 		httpmock.GraphQL(`query OrganizationProjectList\b`),
 		httpmock.StringResponse(`
-			{ "data": { "organization": { "projects": {
-				"nodes": [
-					{ "name": "Triage", "id": "TRIAGEID", "resourcePath": "/orgs/ORG/projects/1"  }
-				],
-				"pageInfo": { "hasNextPage": false }
-			} } } }
-			`))
+		{ "data": { "organization": { "projects": {
+			"nodes": [
+				{ "name": "Triage", "id": "TRIAGEID", "resourcePath": "/orgs/ORG/projects/1"  }
+			],
+			"pageInfo": { "hasNextPage": false }
+		} } } }
+		`))
+	http.Register(
+		httpmock.GraphQL(`query RepositoryProjectV2List\b`),
+		httpmock.StringResponse(`
+		{ "data": { "repository": { "projectsV2": {
+			"nodes": [
+				{ "title": "CleanupV2", "id": "CLEANUPV2ID", "resourcePath": "/OWNER/REPO/projects/3" },
+				{ "title": "RoadmapV2", "id": "ROADMAPV2ID", "resourcePath": "/OWNER/REPO/projects/4" }
+			],
+			"pageInfo": { "hasNextPage": false }
+		} } } }
+		`))
+	http.Register(
+		httpmock.GraphQL(`query OrganizationProjectV2List\b`),
+		httpmock.StringResponse(`
+		{ "data": { "organization": { "projectsV2": {
+			"nodes": [
+				{ "title": "TriageV2", "id": "TRIAGEV2ID", "resourcePath": "/orgs/ORG/projects/2"  }
+			],
+			"pageInfo": { "hasNextPage": false }
+		} } } }
+		`))
 
-	projectPaths, err := ProjectNamesToPaths(client, repo, []string{"Triage", "Roadmap"})
+	projectPaths, err := ProjectNamesToPaths(client, repo, []string{"Triage", "Roadmap", "TriageV2", "RoadmapV2"})
 	if err != nil {
 		t.Fatalf("unexpected error: %v", err)
 	}
 
-	expectedProjectPaths := []string{"ORG/1", "OWNER/REPO/2"}
+	expectedProjectPaths := []string{"ORG/1", "OWNER/REPO/2", "ORG/2", "OWNER/REPO/4"}
 	if !sliceEqual(projectPaths, expectedProjectPaths) {
 		t.Errorf("expected projects paths %v, got %v", expectedProjectPaths, projectPaths)
 	}
