@@ -4,8 +4,10 @@ import (
 	"context"
 	"errors"
 	"fmt"
+	"net"
 	"time"
 
+	"github.com/cenkalti/backoff/v4"
 	"github.com/cli/cli/v2/internal/codespaces/api"
 	"github.com/cli/cli/v2/pkg/liveshare"
 )
@@ -43,13 +45,19 @@ func ConnectToLiveshare(ctx context.Context, progress progressIndicator, session
 			return nil, fmt.Errorf("error starting codespace: %w", err)
 		}
 	}
+	expBackoff := backoff.NewExponentialBackOff()
+
+	expBackoff.Multiplier = 1.1
+	expBackoff.MaxInterval = 10 * time.Second
+	expBackoff.MaxElapsedTime = 5 * time.Minute
 
 	for retries := 0; !connectionReady(codespace); retries++ {
 		if retries > 1 {
-			time.Sleep(1 * time.Second)
+			duration := expBackoff.NextBackOff()
+			time.Sleep(duration)
 		}
 
-		if retries == 30 {
+		if expBackoff.GetElapsedTime() >= expBackoff.MaxElapsedTime {
 			return nil, errors.New("timed out while waiting for the codespace to start")
 		}
 
@@ -63,7 +71,6 @@ func ConnectToLiveshare(ctx context.Context, progress progressIndicator, session
 	defer progress.StopProgressIndicator()
 
 	return liveshare.Connect(ctx, liveshare.Options{
-		ClientName:     "gh",
 		SessionID:      codespace.Connection.SessionID,
 		SessionToken:   codespace.Connection.SessionToken,
 		RelaySAS:       codespace.Connection.RelaySAS,
@@ -72,3 +79,18 @@ func ConnectToLiveshare(ctx context.Context, progress progressIndicator, session
 		Logger:         sessionLogger,
 	})
 }
+
+// ListenTCP starts a localhost tcp listener and returns the listener and bound port
+func ListenTCP(port int) (*net.TCPListener, int, error) {
+	addr, err := net.ResolveTCPAddr("tcp", fmt.Sprintf("127.0.0.1:%d", port))
+	if err != nil {
+		return nil, 0, fmt.Errorf("failed to build tcp address: %w", err)
+	}
+	listener, err := net.ListenTCP("tcp", addr)
+	if err != nil {
+		return nil, 0, fmt.Errorf("failed to listen to local port over tcp: %w", err)
+	}
+	port = listener.Addr().(*net.TCPAddr).Port
+
+	return listener, port, nil
+}
