@@ -24,7 +24,7 @@ func TestGenManDoc(t *testing.T) {
 
 	// We generate on a subcommand so we have both subcommands and parents
 	buf := new(bytes.Buffer)
-	if err := GenMan(echoCmd, header, buf); err != nil {
+	if err := renderMan(echoCmd, header, buf); err != nil {
 		t.Fatal(err)
 	}
 	output := buf.String()
@@ -58,7 +58,7 @@ func TestGenManNoHiddenParents(t *testing.T) {
 		defer func() { f.Hidden = false }()
 	}
 	buf := new(bytes.Buffer)
-	if err := GenMan(echoCmd, header, buf); err != nil {
+	if err := renderMan(echoCmd, header, buf); err != nil {
 		t.Fatal(err)
 	}
 	output := buf.String()
@@ -89,7 +89,7 @@ func TestGenManSeeAlso(t *testing.T) {
 
 	buf := new(bytes.Buffer)
 	header := &GenManHeader{}
-	if err := GenMan(rootCmd, header, buf); err != nil {
+	if err := renderMan(rootCmd, header, buf); err != nil {
 		t.Fatal(err)
 	}
 	scanner := bufio.NewScanner(buf)
@@ -154,7 +154,7 @@ func BenchmarkGenManToFile(b *testing.B) {
 
 	b.ResetTimer()
 	for i := 0; i < b.N; i++ {
-		if err := GenMan(rootCmd, nil, file); err != nil {
+		if err := renderMan(rootCmd, nil, file); err != nil {
 			b.Fatal(err)
 		}
 	}
