@@ -27,6 +27,10 @@ func TestIsEnterprise(t *testing.T) {
 			host: "api.github.localhost",
 			want: false,
 		},
+		{
+			host: "garage.github.com",
+			want: false,
+		},
 		{
 			host: "ghe.io",
 			want: true,
@@ -74,6 +78,10 @@ func TestNormalizeHostname(t *testing.T) {
 			host: "api.github.localhost",
 			want: "github.localhost",
 		},
+		{
+			host: "garage.github.com",
+			want: "github.com",
+		},
 		{
 			host: "GHE.IO",
 			want: "ghe.io",
@@ -144,6 +152,10 @@ func TestGraphQLEndpoint(t *testing.T) {
 			host: "github.localhost",
 			want: "http://api.github.localhost/graphql",
 		},
+		{
+			host: "garage.github.com",
+			want: "https://garage.github.com/api/graphql",
+		},
 		{
 			host: "ghe.io",
 			want: "https://ghe.io/api/graphql",
@@ -171,6 +183,10 @@ func TestRESTPrefix(t *testing.T) {
 			host: "github.localhost",
 			want: "http://api.github.localhost/",
 		},
+		{
+			host: "garage.github.com",
+			want: "https://garage.github.com/api/v3/",
+		},
 		{
 			host: "ghe.io",
 			want: "https://ghe.io/api/v3/",
