@@ -218,6 +218,25 @@ func Test_helperRun(t *testing.T) {
 			`),
 			wantStderr: "",
 		},
+		{
+			name: "noop store operation",
+			opts: CredentialOptions{
+				Operation: "store",
+			},
+		},
+		{
+			name: "noop erase operation",
+			opts: CredentialOptions{
+				Operation: "erase",
+			},
+		},
+		{
+			name: "unknown operation",
+			opts: CredentialOptions{
+				Operation: "unknown",
+			},
+			wantErr: true,
+		},
 	}
 	for _, tt := range tests {
 		t.Run(tt.name, func(t *testing.T) {
