@@ -28,31 +28,7 @@ func TestApp_Create(t *testing.T) {
 		{
 			name: "create codespace with default branch and 30m idle timeout",
 			fields: fields{
-				apiClient: &apiClientMock{
-					GetRepositoryFunc: func(ctx context.Context, nwo string) (*api.Repository, error) {
-						return &api.Repository{
-							ID:            1234,
-							FullName:      nwo,
-							DefaultBranch: "main",
-						}, nil
-					},
-					GetCodespaceBillableOwnerFunc: func(ctx context.Context, nwo string) (*api.User, error) {
-						return &api.User{
-							Login: "monalisa",
-							Type:  "User",
-						}, nil
-					},
-					ListDevContainersFunc: func(ctx context.Context, repoID int, branch string, limit int) ([]api.DevContainerEntry, error) {
-						return []api.DevContainerEntry{{Path: ".devcontainer/devcontainer.json"}}, nil
-					},
-					GetCodespacesMachinesFunc: func(ctx context.Context, repoID int, branch, location string, devcontainerPath string) ([]*api.Machine, error) {
-						return []*api.Machine{
-							{
-								Name:        "GIGA",
-								DisplayName: "Gigabits of a machine",
-							},
-						}, nil
-					},
+				apiClient: apiCreateDefaults(&apiClientMock{
 					CreateCodespaceFunc: func(ctx context.Context, params *api.CreateCodespaceParams) (*api.Codespace, error) {
 						if params.Branch != "main" {
 							return nil, fmt.Errorf("got branch %q, want %q", params.Branch, "main")
@@ -63,14 +39,14 @@ func TestApp_Create(t *testing.T) {
 						if *params.RetentionPeriodMinutes != 2880 {
 							return nil, fmt.Errorf("retention period minutes expected 2880, was %v", params.RetentionPeriodMinutes)
 						}
+						if params.DisplayName != "" {
+							return nil, fmt.Errorf("display name was %q, expected empty", params.DisplayName)
+						}
 						return &api.Codespace{
 							Name: "monalisa-dotfiles-abcd1234",
 						}, nil
 					},
-					GetCodespaceRepoSuggestionsFunc: func(ctx context.Context, partialSearch string, params api.RepoSearchParameters) ([]string, error) {
-						return nil, nil // We can't ask for suggestions without a terminal.
-					},
-				},
+				}),
 			},
 			opts: createOptions{
 				repo:            "monalisa/dotfiles",
@@ -81,32 +57,34 @@ func TestApp_Create(t *testing.T) {
 				retentionPeriod: NullableDuration{durationPtr(48 * time.Hour)},
 			},
 			wantStdout: "monalisa-dotfiles-abcd1234\n",
+			wantStderr: "  ✓ Codespaces usage for this repository is paid for by monalisa\n",
+		},
+		{
+			name: "create with explicit display name",
+			fields: fields{
+				apiClient: apiCreateDefaults(&apiClientMock{
+					CreateCodespaceFunc: func(ctx context.Context, params *api.CreateCodespaceParams) (*api.Codespace, error) {
+						if params.DisplayName != "funky flute" {
+							return nil, fmt.Errorf("expected display name %q, got %q", "funky flute", params.DisplayName)
+						}
+						return &api.Codespace{
+							Name: "monalisa-dotfiles-abcd1234",
+						}, nil
+					},
+				}),
+			},
+			opts: createOptions{
+				repo:        "monalisa/dotfiles",
+				branch:      "main",
+				displayName: "funky flute",
+			},
+			wantStdout: "monalisa-dotfiles-abcd1234\n",
+			wantStderr: "  ✓ Codespaces usage for this repository is paid for by monalisa\n",
 		},
 		{
 			name: "create codespace with default branch shows idle timeout notice if present",
 			fields: fields{
-				apiClient: &apiClientMock{
-					GetRepositoryFunc: func(ctx context.Context, nwo string) (*api.Repository, error) {
-						return &api.Repository{
-							ID:            1234,
-							FullName:      nwo,
-							DefaultBranch: "main",
-						}, nil
-					},
-					GetCodespaceBillableOwnerFunc: func(ctx context.Context, nwo string) (*api.User, error) {
-						return &api.User{
-							Login: "monalisa",
-							Type:  "User",
-						}, nil
-					},
-					GetCodespacesMachinesFunc: func(ctx context.Context, repoID int, branch, location string, devcontainerPath string) ([]*api.Machine, error) {
-						return []*api.Machine{
-							{
-								Name:        "GIGA",
-								DisplayName: "Gigabits of a machine",
-							},
-						}, nil
-					},
+				apiClient: apiCreateDefaults(&apiClientMock{
 					CreateCodespaceFunc: func(ctx context.Context, params *api.CreateCodespaceParams) (*api.Codespace, error) {
 						if params.Branch != "main" {
 							return nil, fmt.Errorf("got branch %q, want %q", params.Branch, "main")
@@ -124,7 +102,7 @@ func TestApp_Create(t *testing.T) {
 							Name: "monalisa-dotfiles-abcd1234",
 						}, nil
 					},
-				},
+				}),
 			},
 			opts: createOptions{
 				repo:             "monalisa/dotfiles",
@@ -135,24 +113,12 @@ func TestApp_Create(t *testing.T) {
 				devContainerPath: ".devcontainer/foobar/devcontainer.json",
 			},
 			wantStdout: "monalisa-dotfiles-abcd1234\n",
+			wantStderr: "  ✓ Codespaces usage for this repository is paid for by monalisa\n",
 		},
 		{
 			name: "create codespace with devcontainer path results in selecting the correct machine type",
 			fields: fields{
-				apiClient: &apiClientMock{
-					GetRepositoryFunc: func(ctx context.Context, nwo string) (*api.Repository, error) {
-						return &api.Repository{
-							ID:            1234,
-							FullName:      nwo,
-							DefaultBranch: "main",
-						}, nil
-					},
-					GetCodespaceBillableOwnerFunc: func(ctx context.Context, nwo string) (*api.User, error) {
-						return &api.User{
-							Login: "monalisa",
-							Type:  "User",
-						}, nil
-					},
+				apiClient: apiCreateDefaults(&apiClientMock{
 					GetCodespacesMachinesFunc: func(ctx context.Context, repoID int, branch, location string, devcontainerPath string) ([]*api.Machine, error) {
 						if devcontainerPath == "" {
 							return []*api.Machine{
@@ -187,6 +153,9 @@ func TestApp_Create(t *testing.T) {
 						if params.DevContainerPath != ".devcontainer/foobar/devcontainer.json" {
 							return nil, fmt.Errorf("got dev container path %q, want %q", params.DevContainerPath, ".devcontainer/foobar/devcontainer.json")
 						}
+						if params.Machine != "MEGA" {
+							return nil, fmt.Errorf("want machine %q, got %q", "MEGA", params.Machine)
+						}
 						return &api.Codespace{
 							Name: "monalisa-dotfiles-abcd1234",
 							Machine: api.CodespaceMachine{
@@ -195,7 +164,7 @@ func TestApp_Create(t *testing.T) {
 							},
 						}, nil
 					},
-				},
+				}),
 			},
 			opts: createOptions{
 				repo:             "monalisa/dotfiles",
@@ -206,35 +175,15 @@ func TestApp_Create(t *testing.T) {
 				devContainerPath: ".devcontainer/foobar/devcontainer.json",
 			},
 			wantStdout: "monalisa-dotfiles-abcd1234\n",
+			wantStderr: "  ✓ Codespaces usage for this repository is paid for by monalisa\n",
 		},
 		{
 			name: "create codespace with default branch with default devcontainer if no path provided and no devcontainer files exist in the repo",
 			fields: fields{
-				apiClient: &apiClientMock{
-					GetRepositoryFunc: func(ctx context.Context, nwo string) (*api.Repository, error) {
-						return &api.Repository{
-							ID:            1234,
-							FullName:      nwo,
-							DefaultBranch: "main",
-						}, nil
-					},
-					GetCodespaceBillableOwnerFunc: func(ctx context.Context, nwo string) (*api.User, error) {
-						return &api.User{
-							Login: "monalisa",
-							Type:  "User",
-						}, nil
-					},
+				apiClient: apiCreateDefaults(&apiClientMock{
 					ListDevContainersFunc: func(ctx context.Context, repoID int, branch string, limit int) ([]api.DevContainerEntry, error) {
 						return []api.DevContainerEntry{}, nil
 					},
-					GetCodespacesMachinesFunc: func(ctx context.Context, repoID int, branch, location string, devcontainerPath string) ([]*api.Machine, error) {
-						return []*api.Machine{
-							{
-								Name:        "GIGA",
-								DisplayName: "Gigabits of a machine",
-							},
-						}, nil
-					},
 					CreateCodespaceFunc: func(ctx context.Context, params *api.CreateCodespaceParams) (*api.Codespace, error) {
 						if params.Branch != "main" {
 							return nil, fmt.Errorf("got branch %q, want %q", params.Branch, "main")
@@ -250,10 +199,7 @@ func TestApp_Create(t *testing.T) {
 							IdleTimeoutNotice: "Idle timeout for this codespace is set to 10 minutes in compliance with your organization's policy",
 						}, nil
 					},
-					GetCodespaceRepoSuggestionsFunc: func(ctx context.Context, partialSearch string, params api.RepoSearchParameters) ([]string, error) {
-						return nil, nil // We can't ask for suggestions without a terminal.
-					},
-				},
+				}),
 			},
 			opts: createOptions{
 				repo:        "monalisa/dotfiles",
@@ -263,30 +209,17 @@ func TestApp_Create(t *testing.T) {
 				idleTimeout: 30 * time.Minute,
 			},
 			wantStdout: "monalisa-dotfiles-abcd1234\n",
-			wantStderr: "Notice: Idle timeout for this codespace is set to 10 minutes in compliance with your organization's policy\n",
+			wantStderr: "  ✓ Codespaces usage for this repository is paid for by monalisa\nNotice: Idle timeout for this codespace is set to 10 minutes in compliance with your organization's policy\n",
 			isTTY:      true,
 		},
 		{
 			name: "returns error when getting devcontainer paths fails",
 			fields: fields{
-				apiClient: &apiClientMock{
-					GetRepositoryFunc: func(ctx context.Context, nwo string) (*api.Repository, error) {
-						return &api.Repository{
-							ID:            1234,
-							FullName:      nwo,
-							DefaultBranch: "main",
-						}, nil
-					},
-					GetCodespaceBillableOwnerFunc: func(ctx context.Context, nwo string) (*api.User, error) {
-						return &api.User{
-							Login: "monalisa",
-							Type:  "User",
-						}, nil
-					},
+				apiClient: apiCreateDefaults(&apiClientMock{
 					ListDevContainersFunc: func(ctx context.Context, repoID int, branch string, limit int) ([]api.DevContainerEntry, error) {
 						return nil, fmt.Errorf("some error")
 					},
-				},
+				}),
 			},
 			opts: createOptions{
 				repo:        "monalisa/dotfiles",
@@ -295,36 +228,13 @@ func TestApp_Create(t *testing.T) {
 				showStatus:  false,
 				idleTimeout: 30 * time.Minute,
 			},
-			wantErr: fmt.Errorf("error getting devcontainer.json paths: some error"),
+			wantErr:    fmt.Errorf("error getting devcontainer.json paths: some error"),
+			wantStderr: "  ✓ Codespaces usage for this repository is paid for by monalisa\n",
 		},
 		{
 			name: "create codespace with default branch does not show idle timeout notice if not conntected to terminal",
 			fields: fields{
-				apiClient: &apiClientMock{
-					GetRepositoryFunc: func(ctx context.Context, nwo string) (*api.Repository, error) {
-						return &api.Repository{
-							ID:            1234,
-							FullName:      nwo,
-							DefaultBranch: "main",
-						}, nil
-					},
-					GetCodespaceBillableOwnerFunc: func(ctx context.Context, nwo string) (*api.User, error) {
-						return &api.User{
-							Login: "monalisa",
-							Type:  "User",
-						}, nil
-					},
-					ListDevContainersFunc: func(ctx context.Context, repoID int, branch string, limit int) ([]api.DevContainerEntry, error) {
-						return []api.DevContainerEntry{}, nil
-					},
-					GetCodespacesMachinesFunc: func(ctx context.Context, repoID int, branch, location string, devcontainerPath string) ([]*api.Machine, error) {
-						return []*api.Machine{
-							{
-								Name:        "GIGA",
-								DisplayName: "Gigabits of a machine",
-							},
-						}, nil
-					},
+				apiClient: apiCreateDefaults(&apiClientMock{
 					CreateCodespaceFunc: func(ctx context.Context, params *api.CreateCodespaceParams) (*api.Codespace, error) {
 						if params.Branch != "main" {
 							return nil, fmt.Errorf("got branch %q, want %q", params.Branch, "main")
@@ -337,10 +247,7 @@ func TestApp_Create(t *testing.T) {
 							IdleTimeoutNotice: "Idle timeout for this codespace is set to 10 minutes in compliance with your organization's policy",
 						}, nil
 					},
-					GetCodespaceRepoSuggestionsFunc: func(ctx context.Context, partialSearch string, params api.RepoSearchParameters) ([]string, error) {
-						return nil, nil // We can't ask for suggestions without a terminal.
-					},
-				},
+				}),
 			},
 			opts: createOptions{
 				repo:        "monalisa/dotfiles",
@@ -350,37 +257,13 @@ func TestApp_Create(t *testing.T) {
 				idleTimeout: 30 * time.Minute,
 			},
 			wantStdout: "monalisa-dotfiles-abcd1234\n",
-			wantStderr: "",
+			wantStderr: "  ✓ Codespaces usage for this repository is paid for by monalisa\n",
 			isTTY:      false,
 		},
 		{
 			name: "create codespace that requires accepting additional permissions",
 			fields: fields{
-				apiClient: &apiClientMock{
-					GetCodespaceBillableOwnerFunc: func(ctx context.Context, nwo string) (*api.User, error) {
-						return &api.User{
-							Login: "monalisa",
-							Type:  "User",
-						}, nil
-					},
-					GetRepositoryFunc: func(ctx context.Context, nwo string) (*api.Repository, error) {
-						return &api.Repository{
-							ID:            1234,
-							FullName:      nwo,
-							DefaultBranch: "main",
-						}, nil
-					},
-					ListDevContainersFunc: func(ctx context.Context, repoID int, branch string, limit int) ([]api.DevContainerEntry, error) {
-						return []api.DevContainerEntry{{Path: ".devcontainer/devcontainer.json"}}, nil
-					},
-					GetCodespacesMachinesFunc: func(ctx context.Context, repoID int, branch, location string, devcontainerPath string) ([]*api.Machine, error) {
-						return []*api.Machine{
-							{
-								Name:        "GIGA",
-								DisplayName: "Gigabits of a machine",
-							},
-						}, nil
-					},
+				apiClient: apiCreateDefaults(&apiClientMock{
 					CreateCodespaceFunc: func(ctx context.Context, params *api.CreateCodespaceParams) (*api.Codespace, error) {
 						if params.Branch != "main" {
 							return nil, fmt.Errorf("got branch %q, want %q", params.Branch, "main")
@@ -392,10 +275,7 @@ func TestApp_Create(t *testing.T) {
 							AllowPermissionsURL: "https://example.com/permissions",
 						}
 					},
-					GetCodespaceRepoSuggestionsFunc: func(ctx context.Context, partialSearch string, params api.RepoSearchParameters) ([]string, error) {
-						return nil, nil // We can't ask for suggestions without a terminal.
-					},
-				},
+				}),
 			},
 			opts: createOptions{
 				repo:        "monalisa/dotfiles",
@@ -405,7 +285,8 @@ func TestApp_Create(t *testing.T) {
 				idleTimeout: 30 * time.Minute,
 			},
 			wantErr: cmdutil.SilentError,
-			wantStderr: `You must authorize or deny additional permissions requested by this codespace before continuing.
+			wantStderr: `  ✓ Codespaces usage for this repository is paid for by monalisa
+You must authorize or deny additional permissions requested by this codespace before continuing.
 Open this URL in your browser to review and authorize additional permissions: example.com/permissions
 Alternatively, you can run "create" with the "--default-permissions" option to continue without authorizing additional permissions.
 `,
@@ -413,18 +294,11 @@ Alternatively, you can run "create" with the "--default-permissions" option to c
 		{
 			name: "returns error when user can't create codepaces for a repository",
 			fields: fields{
-				apiClient: &apiClientMock{
-					GetRepositoryFunc: func(ctx context.Context, nwo string) (*api.Repository, error) {
-						return &api.Repository{
-							ID:            1234,
-							FullName:      nwo,
-							DefaultBranch: "main",
-						}, nil
-					},
+				apiClient: apiCreateDefaults(&apiClientMock{
 					GetCodespaceBillableOwnerFunc: func(ctx context.Context, nwo string) (*api.User, error) {
 						return nil, fmt.Errorf("some error")
 					},
-				},
+				}),
 			},
 			opts: createOptions{
 				repo:        "megacorp/private",
@@ -436,39 +310,45 @@ Alternatively, you can run "create" with the "--default-permissions" option to c
 			wantErr: fmt.Errorf("error checking codespace ownership: some error"),
 		},
 		{
-			name: "mentions billable owner when org covers codepaces for a repository",
+			name: "mentions User as billable owner when org does not cover codepaces for a repository",
 			fields: fields{
-				apiClient: &apiClientMock{
-					GetRepositoryFunc: func(ctx context.Context, nwo string) (*api.Repository, error) {
-						return &api.Repository{
-							ID:            1234,
-							FullName:      nwo,
-							DefaultBranch: "main",
+				apiClient: apiCreateDefaults(&apiClientMock{
+					GetCodespaceBillableOwnerFunc: func(ctx context.Context, nwo string) (*api.User, error) {
+						return &api.User{
+							Type:  "User",
+							Login: "monalisa",
 						}, nil
 					},
+					CreateCodespaceFunc: func(ctx context.Context, params *api.CreateCodespaceParams) (*api.Codespace, error) {
+						return &api.Codespace{
+							Name: "monalisa-dotfiles-abcd1234",
+						}, nil
+					},
+				}),
+			},
+			opts: createOptions{
+				repo:   "monalisa/dotfiles",
+				branch: "main",
+			},
+			wantStderr: "  ✓ Codespaces usage for this repository is paid for by monalisa\n",
+			wantStdout: "monalisa-dotfiles-abcd1234\n",
+		},
+		{
+			name: "mentions Organization as billable owner when org covers codepaces for a repository",
+			fields: fields{
+				apiClient: apiCreateDefaults(&apiClientMock{
 					GetCodespaceBillableOwnerFunc: func(ctx context.Context, nwo string) (*api.User, error) {
 						return &api.User{
 							Type:  "Organization",
 							Login: "megacorp",
 						}, nil
 					},
-					ListDevContainersFunc: func(ctx context.Context, repoID int, branch string, limit int) ([]api.DevContainerEntry, error) {
-						return []api.DevContainerEntry{{Path: ".devcontainer/devcontainer.json"}}, nil
-					},
-					GetCodespacesMachinesFunc: func(ctx context.Context, repoID int, branch, location string, devcontainerPath string) ([]*api.Machine, error) {
-						return []*api.Machine{
-							{
-								Name:        "GIGA",
-								DisplayName: "Gigabits of a machine",
-							},
-						}, nil
-					},
 					CreateCodespaceFunc: func(ctx context.Context, params *api.CreateCodespaceParams) (*api.Codespace, error) {
 						return &api.Codespace{
 							Name: "megacorp-private-abcd1234",
 						}, nil
 					},
-				},
+				}),
 			},
 			opts: createOptions{
 				repo:        "megacorp/private",
@@ -481,31 +361,13 @@ Alternatively, you can run "create" with the "--default-permissions" option to c
 			wantStdout: "megacorp-private-abcd1234\n",
 		},
 		{
-			name: "doesn't mention billable owner when it's the individual",
+			name: "does not mention billable owner when not an expected type",
 			fields: fields{
-				apiClient: &apiClientMock{
-					GetRepositoryFunc: func(ctx context.Context, nwo string) (*api.Repository, error) {
-						return &api.Repository{
-							ID:            1234,
-							FullName:      nwo,
-							DefaultBranch: "main",
-						}, nil
-					},
+				apiClient: apiCreateDefaults(&apiClientMock{
 					GetCodespaceBillableOwnerFunc: func(ctx context.Context, nwo string) (*api.User, error) {
 						return &api.User{
-							Type:  "User",
-							Login: "monalisa",
-						}, nil
-					},
-					ListDevContainersFunc: func(ctx context.Context, repoID int, branch string, limit int) ([]api.DevContainerEntry, error) {
-						return []api.DevContainerEntry{{Path: ".devcontainer/devcontainer.json"}}, nil
-					},
-					GetCodespacesMachinesFunc: func(ctx context.Context, repoID int, branch, location string, devcontainerPath string) ([]*api.Machine, error) {
-						return []*api.Machine{
-							{
-								Name:        "GIGA",
-								DisplayName: "Gigabits of a machine",
-							},
+							Type:  "UnexpectedBillableOwnerType",
+							Login: "mega-owner",
 						}, nil
 					},
 					CreateCodespaceFunc: func(ctx context.Context, params *api.CreateCodespaceParams) (*api.Codespace, error) {
@@ -513,14 +375,10 @@ Alternatively, you can run "create" with the "--default-permissions" option to c
 							Name: "megacorp-private-abcd1234",
 						}, nil
 					},
-				},
+				}),
 			},
 			opts: createOptions{
-				repo:        "megacorp/private",
-				branch:      "",
-				machine:     "GIGA",
-				showStatus:  false,
-				idleTimeout: 30 * time.Minute,
+				repo: "megacorp/private",
 			},
 			wantStdout: "megacorp-private-abcd1234\n",
 		},
@@ -594,6 +452,42 @@ func TestBuildDisplayName(t *testing.T) {
 	}
 }
 
+func apiCreateDefaults(c *apiClientMock) *apiClientMock {
+	if c.GetRepositoryFunc == nil {
+		c.GetRepositoryFunc = func(ctx context.Context, nwo string) (*api.Repository, error) {
+			return &api.Repository{
+				ID:            1234,
+				FullName:      nwo,
+				DefaultBranch: "main",
+			}, nil
+		}
+	}
+	if c.GetCodespaceBillableOwnerFunc == nil {
+		c.GetCodespaceBillableOwnerFunc = func(ctx context.Context, nwo string) (*api.User, error) {
+			return &api.User{
+				Login: "monalisa",
+				Type:  "User",
+			}, nil
+		}
+	}
+	if c.ListDevContainersFunc == nil {
+		c.ListDevContainersFunc = func(ctx context.Context, repoID int, branch string, limit int) ([]api.DevContainerEntry, error) {
+			return []api.DevContainerEntry{{Path: ".devcontainer/devcontainer.json"}}, nil
+		}
+	}
+	if c.GetCodespacesMachinesFunc == nil {
+		c.GetCodespacesMachinesFunc = func(ctx context.Context, repoID int, branch, location string, devcontainerPath string) ([]*api.Machine, error) {
+			return []*api.Machine{
+				{
+					Name:        "GIGA",
+					DisplayName: "Gigabits of a machine",
+				},
+			}, nil
+		}
+	}
+	return c
+}
+
 func durationPtr(d time.Duration) *time.Duration {
 	return &d
 }
