@@ -263,5 +263,5 @@ func testingPortsApp() *App {
 
 	ios, _, _, _ := iostreams.Test()
 
-	return NewApp(ios, nil, apiMock, nil)
+	return NewApp(ios, nil, apiMock, nil, nil)
 }
