@@ -5,27 +5,33 @@ import (
 	"fmt"
 
 	"github.com/cli/cli/v2/internal/codespaces/api"
+	"github.com/cli/cli/v2/internal/codespaces/rpc"
 	"github.com/spf13/cobra"
 )
 
 func newRebuildCmd(app *App) *cobra.Command {
 	var codespace string
+	var fullRebuild bool
 
 	rebuildCmd := &cobra.Command{
 		Use:   "rebuild",
 		Short: "Rebuild a codespace",
-		Args:  cobra.NoArgs,
+		Long: `Rebuilding recreates your codespace. Your code and any current changes will be
+preserved. Your codespace will be rebuilt using your working directory's
+dev container. A full rebuild also removes cached Docker images.`,
+		Args: cobra.NoArgs,
 		RunE: func(cmd *cobra.Command, args []string) error {
-			return app.Rebuild(cmd.Context(), codespace)
+			return app.Rebuild(cmd.Context(), codespace, fullRebuild)
 		},
 	}
 
-	rebuildCmd.Flags().StringVarP(&codespace, "codespace", "c", "", "Name of the codespace")
+	rebuildCmd.Flags().StringVarP(&codespace, "codespace", "c", "", "name of the codespace")
+	rebuildCmd.Flags().BoolVar(&fullRebuild, "full", false, "perform a full rebuild")
 
 	return rebuildCmd
 }
 
-func (a *App) Rebuild(ctx context.Context, codespaceName string) (err error) {
+func (a *App) Rebuild(ctx context.Context, codespaceName string, full bool) (err error) {
 	ctx, cancel := context.WithCancel(ctx)
 	defer cancel()
 
@@ -46,7 +52,13 @@ func (a *App) Rebuild(ctx context.Context, codespaceName string) (err error) {
 	}
 	defer safeClose(session, &err)
 
-	err = session.RebuildContainer(ctx)
+	invoker, err := rpc.CreateInvoker(ctx, session)
+	if err != nil {
+		return err
+	}
+	defer safeClose(invoker, &err)
+
+	err = invoker.RebuildContainer(ctx, full)
 	if err != nil {
 		return fmt.Errorf("rebuilding codespace via session: %w", err)
 	}
