@@ -6,10 +6,10 @@ import (
 	"context"
 	"errors"
 	"fmt"
-	"io"
 	"log"
-	"net"
 	"os"
+	"os/exec"
+	"path"
 	"path/filepath"
 	"strings"
 	"sync"
@@ -18,9 +18,12 @@ import (
 	"github.com/MakeNowJust/heredoc"
 	"github.com/cli/cli/v2/internal/codespaces"
 	"github.com/cli/cli/v2/internal/codespaces/api"
+	"github.com/cli/cli/v2/internal/codespaces/rpc"
+	"github.com/cli/cli/v2/internal/config"
 	"github.com/cli/cli/v2/pkg/cmdutil"
 	"github.com/cli/cli/v2/pkg/liveshare"
 	"github.com/cli/cli/v2/pkg/ssh"
+	"github.com/cli/safeexec"
 	"github.com/spf13/cobra"
 )
 
@@ -30,6 +33,8 @@ import (
 const automaticPrivateKeyNameOld = "codespaces"
 const automaticPrivateKeyName = "codespaces.auto"
 
+var errKeyFileNotFound = errors.New("SSH key file does not exist")
+
 type sshOptions struct {
 	codespace  string
 	profile    string
@@ -54,23 +59,24 @@ func newSSHCmd(app *App) *cobra.Command {
 			By default, the 'ssh' command will create a public/private ssh key pair to  
 			authenticate with the codespace inside the ~/.ssh directory.
 
-			The 'ssh' command also supports deeper integration with OpenSSH using a
-			'--config' option that generates per-codespace ssh configuration in OpenSSH
-			format. Including this configuration in your ~/.ssh/config improves the user
-			experience of tools that integrate with OpenSSH, such as bash/zsh completion of
-			ssh hostnames, remote path completion for scp/rsync/sshfs, git ssh remotes, and
-			so on.
+			The 'ssh' command also supports deeper integration with OpenSSH using a '--config'
+			option that generates per-codespace ssh configuration in OpenSSH format.
+			Including this configuration in your ~/.ssh/config improves the user experience
+			of tools that integrate with OpenSSH, such as bash/zsh completion of ssh hostnames,
+			remote path completion for scp/rsync/sshfs, git ssh remotes, and so on.
 
 			Once that is set up (see the second example below), you can ssh to codespaces as
 			if they were ordinary remote hosts (using 'ssh', not 'gh cs ssh').
 
 			Note that the codespace you are connecting to must have an SSH server pre-installed.
 			If the docker image being used for the codespace does not have an SSH server,
-			install it in your Dockerfile or you can try adding the following snippet
-			in your devcontainer.json:
-			
+			install it in your Dockerfile or, for codespaces that use Debian-based images,
+			you can add the following to your devcontainer.json:
+
 			"features": {
-				"sshd": "latest"
+				"ghcr.io/devcontainers/features/sshd:1": {
+					"version": "latest"
+				}
 			}
 		`),
 		Example: heredoc.Doc(`
@@ -140,15 +146,16 @@ func (a *App) SSH(ctx context.Context, sshArgs []string, opts sshOptions) (err e
 	}
 
 	sshContext := ssh.Context{}
-	startSSHOptions := liveshare.StartSSHServerOptions{}
+	startSSHOptions := rpc.StartSSHServerOptions{}
 
-	if shouldUseAutomaticSSHKeys(args, opts) {
-		keyPair, err := setupAutomaticSSHKeys(sshContext)
-		if err != nil {
-			return fmt.Errorf("failed to generate ssh keys: %w", err)
-		}
+	keyPair, shouldAddArg, err := selectSSHKeys(ctx, sshContext, args, opts)
+	if err != nil {
+		return fmt.Errorf("selecting ssh keys: %w", err)
+	}
 
-		startSSHOptions.UserPublicKeyFile = keyPair.PublicKeyPath
+	startSSHOptions.UserPublicKeyFile = keyPair.PublicKeyPath
+
+	if shouldAddArg {
 		// For both cp and ssh, flags need to come first in the args (before a command in ssh and files in cp), so prepend this flag
 		args = append([]string{"-i", keyPair.PrivateKeyPath}, args...)
 	}
@@ -165,7 +172,13 @@ func (a *App) SSH(ctx context.Context, sshArgs []string, opts sshOptions) (err e
 	defer safeClose(session, &err)
 
 	a.StartProgressIndicatorWithLabel("Fetching SSH Details")
-	remoteSSHServerPort, sshUser, err := session.StartSSHServerWithOptions(ctx, startSSHOptions)
+	invoker, err := rpc.CreateInvoker(ctx, session)
+	if err != nil {
+		return err
+	}
+	defer safeClose(invoker, &err)
+
+	remoteSSHServerPort, sshUser, err := invoker.StartSSHServerWithOptions(ctx, startSSHOptions)
 	a.StopProgressIndicator()
 	if err != nil {
 		return fmt.Errorf("error getting ssh server details: %w", err)
@@ -173,7 +186,7 @@ func (a *App) SSH(ctx context.Context, sshArgs []string, opts sshOptions) (err e
 
 	if opts.stdio {
 		fwd := liveshare.NewPortForwarder(session, "sshd", remoteSSHServerPort, true)
-		stdio := newReadWriteCloser(os.Stdin, os.Stdout)
+		stdio := liveshare.NewReadWriteHalfCloser(os.Stdin, os.Stdout)
 		err := fwd.Forward(ctx, stdio) // always non-nil
 		return fmt.Errorf("tunnel closed: %w", err)
 	}
@@ -184,12 +197,11 @@ func (a *App) SSH(ctx context.Context, sshArgs []string, opts sshOptions) (err e
 	// Ensure local port is listening before client (Shell) connects.
 	// Unless the user specifies a server port, localSSHServerPort is 0
 	// and thus the client will pick a random port.
-	listen, err := net.Listen("tcp", fmt.Sprintf("127.0.0.1:%d", localSSHServerPort))
+	listen, localSSHServerPort, err := codespaces.ListenTCP(localSSHServerPort)
 	if err != nil {
 		return err
 	}
 	defer listen.Close()
-	localSSHServerPort = listen.Addr().(*net.TCPAddr).Port
 
 	connectDestination := opts.profile
 	if connectDestination == "" {
@@ -225,28 +237,93 @@ func (a *App) SSH(ctx context.Context, sshArgs []string, opts sshOptions) (err e
 	}
 }
 
-func shouldUseAutomaticSSHKeys(args []string, opts sshOptions) bool {
-	if opts.profile != "" {
-		// The profile may specify the identity file so cautiously don't override anything with that option
-		return false
-	}
+// selectSSHKeys evaluates available key pairs and select which should be used to connect to the codespace
+// using the precedence rules below. If there is no error, a keypair is always returned and additionally a
+// bool flag is returned to specify if the private key need be appended to the ssh arguments (it doesn't need
+// to be if the key was selected from a -i argument).
+//
+// Precedence rules:
+// 1. Key which is specified by -i
+// 2. Automatic key, if it already exists
+// 3. First valid keypair in ssh config (according to ssh -G)
+// 4. Automatic key, newly created
+func selectSSHKeys(
+	ctx context.Context,
+	sshContext ssh.Context,
+	args []string,
+	opts sshOptions,
+) (*ssh.KeyPair, bool, error) {
+	customConfigPath := ""
+	for i := 0; i < len(args); i += 1 {
+		arg := args[i]
 
-	for _, arg := range args {
 		if arg == "-i" {
-			// User specified the identity file so it should exist
-			return false
+			if i+1 >= len(args) {
+				return nil, false, errors.New("missing value to -i argument")
+			}
+
+			// User manually specified an identity file so just trust it is correct
+			return &ssh.KeyPair{
+				PrivateKeyPath: args[i+1],
+				PublicKeyPath:  args[i+1] + ".pub",
+			}, false, nil
 		}
 
-		if arg == "-F" {
-			// User specified a config file so, similar to profile, cautiously don't override settings
-			return false
+		if arg == "-F" && i+1 < len(args) {
+			// ssh only pays attention to that last specified -F value, so it's correct to overwrite here
+			customConfigPath = args[i+1]
 		}
 	}
 
-	return true
+	if autoKeyPair := automaticSSHKeyPair(sshContext); autoKeyPair != nil {
+		// If the automatic keys already exist, just use them
+		return autoKeyPair, true, nil
+	}
+
+	keyPair, err := firstConfiguredKeyPair(ctx, customConfigPath, opts.profile)
+	if err != nil {
+		if !errors.Is(err, errKeyFileNotFound) {
+			return nil, false, fmt.Errorf("checking configured keys: %w", err)
+		}
+
+		// no valid key in ssh config, generate one
+		keyPair, err = generateAutomaticSSHKeys(sshContext)
+		if err != nil {
+			return nil, false, fmt.Errorf("generating automatic keypair: %w", err)
+		}
+	}
+
+	return keyPair, true, nil
 }
 
-func setupAutomaticSSHKeys(sshContext ssh.Context) (*ssh.KeyPair, error) {
+// automaticSSHKeyPair returns the paths to the automatic key pair files, if they both exist
+func automaticSSHKeyPair(sshContext ssh.Context) *ssh.KeyPair {
+	publicKeys, err := sshContext.LocalPublicKeys()
+	if err != nil {
+		// The error would be that the .ssh dir doesn't exist, which just means that the keypair also doesn't exist
+		return nil
+	}
+
+	for _, publicKey := range publicKeys {
+		if filepath.Base(publicKey) != automaticPrivateKeyName+".pub" {
+			continue
+		}
+
+		privateKey := strings.TrimSuffix(publicKey, ".pub")
+
+		_, err := os.Stat(privateKey)
+		if err == nil {
+			return &ssh.KeyPair{
+				PrivateKeyPath: privateKey,
+				PublicKeyPath:  publicKey,
+			}
+		}
+	}
+
+	return nil
+}
+
+func generateAutomaticSSHKeys(sshContext ssh.Context) (*ssh.KeyPair, error) {
 	keyPair := checkAndUpdateOldKeyPair(sshContext)
 	if keyPair != nil {
 		return keyPair, nil
@@ -307,6 +384,88 @@ func checkAndUpdateOldKeyPair(sshContext ssh.Context) *ssh.KeyPair {
 	return nil
 }
 
+// firstConfiguredKeyPair reads the effective configuration for a localhost
+// connection and returns the first valid key pair which would be tried for authentication
+func firstConfiguredKeyPair(
+	ctx context.Context,
+	customConfigFile string,
+	customHost string,
+) (*ssh.KeyPair, error) {
+	sshExe, err := safeexec.LookPath("ssh")
+	if err != nil {
+		return nil, fmt.Errorf("could not find ssh executable: %w", err)
+	}
+
+	// The -G option tells ssh to output the effective config for the given host, but not connect
+	sshGArgs := []string{"-G"}
+
+	if customConfigFile != "" {
+		sshGArgs = append(sshGArgs, "-F", customConfigFile)
+	}
+
+	if customHost != "" {
+		sshGArgs = append(sshGArgs, customHost)
+	} else {
+		sshGArgs = append(sshGArgs, "localhost")
+	}
+
+	sshGCmd := exec.CommandContext(ctx, sshExe, sshGArgs...)
+	configBytes, err := sshGCmd.Output()
+	if err != nil {
+		return nil, fmt.Errorf("could not load ssh configuration: %w", err)
+	}
+
+	configLines := strings.Split(string(configBytes), "\n")
+	for _, line := range configLines {
+		line = strings.TrimSpace(line)
+
+		if strings.HasPrefix(line, "identityfile ") {
+			privateKeyPath := strings.SplitN(line, " ", 2)[1]
+
+			keypair, err := keypairForPrivateKey(privateKeyPath)
+			if errors.Is(err, errKeyFileNotFound) {
+				continue
+			}
+			if err != nil {
+				return nil, fmt.Errorf("loading ssh config: %w", err)
+			}
+
+			return keypair, nil
+		}
+	}
+
+	return nil, errKeyFileNotFound
+}
+
+// keypairForPrivateKey returns the KeyPair with the specified private key if it and the public key both exist
+func keypairForPrivateKey(privateKeyPath string) (*ssh.KeyPair, error) {
+	if strings.HasPrefix(privateKeyPath, "~") {
+		userHomeDir, err := os.UserHomeDir()
+		if err != nil {
+			return nil, fmt.Errorf("getting home dir: %w", err)
+		}
+
+		// os.Stat can't handle ~, so convert it to the real path
+		privateKeyPath = strings.Replace(privateKeyPath, "~", userHomeDir, 1)
+	}
+
+	// The default configuration includes standard keys like id_rsa or id_ed25519,
+	// but these may not actually exist
+	if _, err := os.Stat(privateKeyPath); err != nil {
+		return nil, errKeyFileNotFound
+	}
+
+	publicKeyPath := privateKeyPath + ".pub"
+	if _, err := os.Stat(publicKeyPath); err != nil {
+		return nil, errKeyFileNotFound
+	}
+
+	return &ssh.KeyPair{
+		PrivateKeyPath: privateKeyPath,
+		PublicKeyPath:  publicKeyPath,
+	}, nil
+}
+
 func (a *App) printOpenSSHConfig(ctx context.Context, opts sshOptions) (err error) {
 	ctx, cancel := context.WithCancel(ctx)
 	defer cancel()
@@ -353,11 +512,18 @@ func (a *App) printOpenSSHConfig(ctx context.Context, opts sshOptions) (err erro
 			} else {
 				defer safeClose(session, &err)
 
-				_, result.user, err = session.StartSSHServer(ctx)
+				invoker, err := rpc.CreateInvoker(ctx, session)
 				if err != nil {
-					result.err = fmt.Errorf("error getting ssh server details: %w", err)
+					result.err = fmt.Errorf("error connecting to codespace: %w", err)
 				} else {
-					result.codespace = cs
+					defer safeClose(invoker, &err)
+
+					_, result.user, err = invoker.StartSSHServer(ctx)
+					if err != nil {
+						result.err = fmt.Errorf("error getting ssh server details: %w", err)
+					} else {
+						result.codespace = cs
+					}
 				}
 			}
 
@@ -370,26 +536,26 @@ func (a *App) printOpenSSHConfig(ctx context.Context, opts sshOptions) (err erro
 		close(sshUsers)
 	}()
 
-	// While the above fetches are running, ensure that the user has keys installed.
-	// That lets us report a more useful error message if they don't.
-	if err = checkAuthorizedKeys(ctx, a.apiClient); err != nil {
-		return err
-	}
-
 	t, err := template.New("ssh_config").Parse(heredoc.Doc(`
 		Host cs.{{.Name}}.{{.EscapedRef}}
 			User {{.SSHUser}}
-			ProxyCommand {{.GHExec}} cs ssh -c {{.Name}} --stdio
+			ProxyCommand {{.GHExec}} cs ssh -c {{.Name}} --stdio -- -i {{.AutomaticIdentityFilePath}}
 			UserKnownHostsFile=/dev/null
 			StrictHostKeyChecking no
 			LogLevel quiet
 			ControlMaster auto
+			IdentityFile {{.AutomaticIdentityFilePath}}
 
 	`))
 	if err != nil {
 		return fmt.Errorf("error formatting template: %w", err)
 	}
 
+	automaticIdentityFilePath, err := automaticPrivateKeyPath()
+	if err != nil {
+		return fmt.Errorf("error finding .ssh directory: %w", err)
+	}
+
 	ghExec := a.executable.Executable()
 	for result := range sshUsers {
 		if result.err != nil {
@@ -410,17 +576,19 @@ func (a *App) printOpenSSHConfig(ctx context.Context, opts sshOptions) (err erro
 		// flattened to '-' to prevent problems with tab completion or when the
 		// hostname appears in ControlMaster socket paths.
 		type codespaceSSHConfig struct {
-			Name       string // the codespace name, passed to `ssh -c`
-			EscapedRef string // the currently checked-out branch
-			SSHUser    string // the remote ssh username
-			GHExec     string // path used for invoking the current `gh` binary
+			Name                      string // the codespace name, passed to `ssh -c`
+			EscapedRef                string // the currently checked-out branch
+			SSHUser                   string // the remote ssh username
+			GHExec                    string // path used for invoking the current `gh` binary
+			AutomaticIdentityFilePath string // path used for automatic private key `gh cs ssh` would generate
 		}
 
 		conf := codespaceSSHConfig{
-			Name:       result.codespace.Name,
-			EscapedRef: strings.ReplaceAll(result.codespace.GitStatus.Ref, "/", "-"),
-			SSHUser:    result.user,
-			GHExec:     ghExec,
+			Name:                      result.codespace.Name,
+			EscapedRef:                strings.ReplaceAll(result.codespace.GitStatus.Ref, "/", "-"),
+			SSHUser:                   result.user,
+			GHExec:                    ghExec,
+			AutomaticIdentityFilePath: automaticIdentityFilePath,
 		}
 		if err := t.Execute(a.io.Out, conf); err != nil {
 			return err
@@ -430,6 +598,15 @@ func (a *App) printOpenSSHConfig(ctx context.Context, opts sshOptions) (err erro
 	return status
 }
 
+func automaticPrivateKeyPath() (string, error) {
+	sshDir, err := config.HomeDirPath(".ssh")
+	if err != nil {
+		return "", err
+	}
+
+	return path.Join(sshDir, automaticPrivateKeyName), nil
+}
+
 type cpOptions struct {
 	sshOptions
 	recursive bool // -r
@@ -565,21 +742,3 @@ func (fl *fileLogger) Name() string {
 func (fl *fileLogger) Close() error {
 	return fl.f.Close()
 }
-
-type combinedReadWriteCloser struct {
-	io.ReadCloser
-	io.WriteCloser
-}
-
-func newReadWriteCloser(reader io.ReadCloser, writer io.WriteCloser) io.ReadWriteCloser {
-	return &combinedReadWriteCloser{reader, writer}
-}
-
-func (crwc *combinedReadWriteCloser) Close() error {
-	werr := crwc.WriteCloser.Close()
-	rerr := crwc.ReadCloser.Close()
-	if werr != nil {
-		return werr
-	}
-	return rerr
-}
