@@ -23,9 +23,10 @@ func NewCmdConfigList(f *cmdutil.Factory, runF func(*ListOptions) error) *cobra.
 	}
 
 	cmd := &cobra.Command{
-		Use:   "list",
-		Short: "Print a list of configuration keys and values",
-		Args:  cobra.ExactArgs(0),
+		Use:     "list",
+		Short:   "Print a list of configuration keys and values",
+		Aliases: []string{"ls"},
+		Args:    cobra.ExactArgs(0),
 		RunE: func(cmd *cobra.Command, args []string) error {
 			if runF != nil {
 				return runF(opts)
@@ -50,16 +51,13 @@ func listRun(opts *ListOptions) error {
 	if opts.Hostname != "" {
 		host = opts.Hostname
 	} else {
-		host, err = cfg.DefaultHost()
-		if err != nil {
-			return err
-		}
+		host, _ = cfg.DefaultHost()
 	}
 
 	configOptions := config.ConfigOptions()
 
 	for _, key := range configOptions {
-		val, err := cfg.Get(host, key.Key)
+		val, err := cfg.GetOrDefault(host, key.Key)
 		if err != nil {
 			return err
 		}
