@@ -1,6 +1,7 @@
 package clone
 
 import (
+	"context"
 	"fmt"
 	"net/http"
 
@@ -16,6 +17,7 @@ import (
 
 type CloneOptions struct {
 	HttpClient func() (*http.Client, error)
+	GitClient  *git.Client
 	Config     func() (config.Config, error)
 	IO         *iostreams.IOStreams
 
@@ -28,6 +30,7 @@ func NewCmdClone(f *cmdutil.Factory, runF func(*CloneOptions) error) *cobra.Comm
 	opts := &CloneOptions{
 		IO:         f.IOStreams,
 		HttpClient: f.HttpClient,
+		GitClient:  f.GitClient,
 		Config:     f.Config,
 	}
 
@@ -84,7 +87,7 @@ func cloneRun(opts *CloneOptions) error {
 		gistURL = formatRemoteURL(hostname, gistURL, protocol)
 	}
 
-	_, err := git.RunClone(gistURL, opts.GitArgs)
+	_, err := opts.GitClient.Clone(context.Background(), gistURL, opts.GitArgs)
 	if err != nil {
 		return err
 	}
