@@ -6,8 +6,10 @@ import (
 	cmdComment "github.com/cli/cli/v2/pkg/cmd/issue/comment"
 	cmdCreate "github.com/cli/cli/v2/pkg/cmd/issue/create"
 	cmdDelete "github.com/cli/cli/v2/pkg/cmd/issue/delete"
+	cmdDevelop "github.com/cli/cli/v2/pkg/cmd/issue/develop"
 	cmdEdit "github.com/cli/cli/v2/pkg/cmd/issue/edit"
 	cmdList "github.com/cli/cli/v2/pkg/cmd/issue/list"
+	cmdLock "github.com/cli/cli/v2/pkg/cmd/issue/lock"
 	cmdPin "github.com/cli/cli/v2/pkg/cmd/issue/pin"
 	cmdReopen "github.com/cli/cli/v2/pkg/cmd/issue/reopen"
 	cmdStatus "github.com/cli/cli/v2/pkg/cmd/issue/status"
@@ -29,29 +31,37 @@ func NewCmdIssue(f *cmdutil.Factory) *cobra.Command {
 			$ gh issue view 123 --web
 		`),
 		Annotations: map[string]string{
-			"IsCore": "true",
 			"help:arguments": heredoc.Doc(`
 				An issue can be supplied as argument in any of the following formats:
 				- by number, e.g. "123"; or
 				- by URL, e.g. "https://github.com/OWNER/REPO/issues/123".
 			`),
 		},
+		GroupID: "core",
 	}
 
 	cmdutil.EnableRepoOverride(cmd, f)
 
-	cmd.AddCommand(cmdClose.NewCmdClose(f, nil))
-	cmd.AddCommand(cmdCreate.NewCmdCreate(f, nil))
-	cmd.AddCommand(cmdList.NewCmdList(f, nil))
-	cmd.AddCommand(cmdReopen.NewCmdReopen(f, nil))
-	cmd.AddCommand(cmdStatus.NewCmdStatus(f, nil))
-	cmd.AddCommand(cmdView.NewCmdView(f, nil))
-	cmd.AddCommand(cmdComment.NewCmdComment(f, nil))
-	cmd.AddCommand(cmdDelete.NewCmdDelete(f, nil))
-	cmd.AddCommand(cmdEdit.NewCmdEdit(f, nil))
-	cmd.AddCommand(cmdTransfer.NewCmdTransfer(f, nil))
-	cmd.AddCommand(cmdPin.NewCmdPin(f, nil))
-	cmd.AddCommand(cmdUnpin.NewCmdUnpin(f, nil))
+	cmdutil.AddGroup(cmd, "General commands",
+		cmdList.NewCmdList(f, nil),
+		cmdCreate.NewCmdCreate(f, nil),
+		cmdStatus.NewCmdStatus(f, nil),
+	)
+
+	cmdutil.AddGroup(cmd, "Targeted commands",
+		cmdView.NewCmdView(f, nil),
+		cmdComment.NewCmdComment(f, nil),
+		cmdClose.NewCmdClose(f, nil),
+		cmdReopen.NewCmdReopen(f, nil),
+		cmdEdit.NewCmdEdit(f, nil),
+		cmdDevelop.NewCmdDevelop(f, nil),
+		cmdLock.NewCmdLock(f, cmd.Name(), nil),
+		cmdLock.NewCmdUnlock(f, cmd.Name(), nil),
+		cmdPin.NewCmdPin(f, nil),
+		cmdUnpin.NewCmdUnpin(f, nil),
+		cmdTransfer.NewCmdTransfer(f, nil),
+		cmdDelete.NewCmdDelete(f, nil),
+	)
 
 	return cmd
 }
