@@ -1,6 +1,7 @@
 package close
 
 import (
+	"context"
 	"fmt"
 	"net/http"
 
@@ -15,6 +16,7 @@ import (
 
 type CloseOptions struct {
 	HttpClient func() (*http.Client, error)
+	GitClient  *git.Client
 	IO         *iostreams.IOStreams
 	Branch     func() (string, error)
 
@@ -30,6 +32,7 @@ func NewCmdClose(f *cmdutil.Factory, runF func(*CloseOptions) error) *cobra.Comm
 	opts := &CloseOptions{
 		IO:         f.IOStreams,
 		HttpClient: f.HttpClient,
+		GitClient:  f.GitClient,
 		Branch:     f.Branch,
 	}
 
@@ -108,9 +111,10 @@ func closeRun(opts *CloseOptions) error {
 	fmt.Fprintf(opts.IO.ErrOut, "%s Closed pull request #%d (%s)\n", cs.SuccessIconWithColor(cs.Red), pr.Number, pr.Title)
 
 	if opts.DeleteBranch {
+		ctx := context.Background()
 		branchSwitchString := ""
 		apiClient := api.NewClientFromHTTP(httpClient)
-		localBranchExists := git.HasLocalBranch(pr.HeadRefName)
+		localBranchExists := opts.GitClient.HasLocalBranch(ctx, pr.HeadRefName)
 
 		if opts.DeleteLocalBranch {
 			if localBranchExists {
@@ -125,13 +129,13 @@ func closeRun(opts *CloseOptions) error {
 					if err != nil {
 						return err
 					}
-					err = git.CheckoutBranch(branchToSwitchTo)
+					err = opts.GitClient.CheckoutBranch(ctx, branchToSwitchTo)
 					if err != nil {
 						return err
 					}
 				}
 
-				if err := git.DeleteLocalBranch(pr.HeadRefName); err != nil {
+				if err := opts.GitClient.DeleteLocalBranch(ctx, pr.HeadRefName); err != nil {
 					return fmt.Errorf("failed to delete local branch %s: %w", cs.Cyan(pr.HeadRefName), err)
 				}
 
