@@ -162,6 +162,48 @@ func TestPRReady_alreadyReady(t *testing.T) {
 	assert.Equal(t, "! Pull request #123 is already \"ready for review\"\n", output.Stderr())
 }
 
+func TestPRReadyUndo(t *testing.T) {
+	http := &httpmock.Registry{}
+	defer http.Verify(t)
+
+	shared.RunCommandFinder("123", &api.PullRequest{
+		ID:      "THE-ID",
+		Number:  123,
+		State:   "OPEN",
+		IsDraft: false,
+	}, ghrepo.New("OWNER", "REPO"))
+
+	http.Register(
+		httpmock.GraphQL(`mutation ConvertPullRequestToDraft\b`),
+		httpmock.GraphQLMutation(`{"id": "THE-ID"}`,
+			func(inputs map[string]interface{}) {
+				assert.Equal(t, inputs["pullRequestId"], "THE-ID")
+			}),
+	)
+
+	output, err := runCommand(http, true, "123 --undo")
+	assert.NoError(t, err)
+	assert.Equal(t, "", output.String())
+	assert.Equal(t, "✓ Pull request #123 is converted to \"draft\"\n", output.Stderr())
+}
+
+func TestPRReadyUndo_alreadyDraft(t *testing.T) {
+	http := &httpmock.Registry{}
+	defer http.Verify(t)
+
+	shared.RunCommandFinder("123", &api.PullRequest{
+		ID:      "THE-ID",
+		Number:  123,
+		State:   "OPEN",
+		IsDraft: true,
+	}, ghrepo.New("OWNER", "REPO"))
+
+	output, err := runCommand(http, true, "123 --undo")
+	assert.NoError(t, err)
+	assert.Equal(t, "", output.String())
+	assert.Equal(t, "! Pull request #123 is already \"in draft\"\n", output.Stderr())
+}
+
 func TestPRReady_closed(t *testing.T) {
 	http := &httpmock.Registry{}
 	defer http.Verify(t)
