@@ -35,6 +35,29 @@ func UpdateIssue(httpClient *http.Client, repo ghrepo.Interface, id string, isPR
 		}
 	}
 
+	// updateIssue mutation does not support ProjectsV2 so do them in a seperate request.
+	if options.Projects.Edited {
+		wg.Go(func() error {
+			apiClient := api.NewClientFromHTTP(httpClient)
+			addIds, removeIds, err := options.ProjectV2Ids()
+			if err != nil {
+				return err
+			}
+			if addIds == nil && removeIds == nil {
+				return nil
+			}
+			toAdd := make(map[string]string, len(*addIds))
+			toRemove := make(map[string]string, len(*removeIds))
+			for _, p := range *addIds {
+				toAdd[p] = id
+			}
+			for _, p := range *removeIds {
+				toRemove[p] = options.Projects.ProjectItems[p]
+			}
+			return api.UpdateProjectV2Items(apiClient, repo, toAdd, toRemove)
+		})
+	}
+
 	if dirtyExcludingLabels(options) {
 		wg.Go(func() error {
 			return replaceIssueFields(httpClient, repo, id, isPR, options)
