@@ -1,6 +1,7 @@
 package status
 
 import (
+	"context"
 	"errors"
 	"fmt"
 	"net/http"
@@ -9,33 +10,36 @@ import (
 	"strings"
 
 	"github.com/cli/cli/v2/api"
-	"github.com/cli/cli/v2/context"
+	ghContext "github.com/cli/cli/v2/context"
 	"github.com/cli/cli/v2/git"
 	"github.com/cli/cli/v2/internal/config"
 	"github.com/cli/cli/v2/internal/ghrepo"
+	"github.com/cli/cli/v2/internal/text"
 	"github.com/cli/cli/v2/pkg/cmd/pr/shared"
 	"github.com/cli/cli/v2/pkg/cmdutil"
 	"github.com/cli/cli/v2/pkg/iostreams"
-	"github.com/cli/cli/v2/pkg/text"
 	"github.com/spf13/cobra"
 )
 
 type StatusOptions struct {
 	HttpClient func() (*http.Client, error)
+	GitClient  *git.Client
 	Config     func() (config.Config, error)
 	IO         *iostreams.IOStreams
 	BaseRepo   func() (ghrepo.Interface, error)
-	Remotes    func() (context.Remotes, error)
+	Remotes    func() (ghContext.Remotes, error)
 	Branch     func() (string, error)
 
 	HasRepoOverride bool
 	Exporter        cmdutil.Exporter
+	ConflictStatus  bool
 }
 
 func NewCmdStatus(f *cmdutil.Factory, runF func(*StatusOptions) error) *cobra.Command {
 	opts := &StatusOptions{
 		IO:         f.IOStreams,
 		HttpClient: f.HttpClient,
+		GitClient:  f.GitClient,
 		Config:     f.Config,
 		Remotes:    f.Remotes,
 		Branch:     f.Branch,
@@ -57,6 +61,7 @@ func NewCmdStatus(f *cmdutil.Factory, runF func(*StatusOptions) error) *cobra.Co
 		},
 	}
 
+	cmd.Flags().BoolVarP(&opts.ConflictStatus, "conflict-status", "c", false, "Display the merge conflict status of each pull request")
 	cmdutil.AddJSONFlags(cmd, &opts.Exporter, api.PullRequestFields)
 
 	return cmd
@@ -84,20 +89,22 @@ func statusRun(opts *StatusOptions) error {
 		}
 
 		remotes, _ := opts.Remotes()
-		currentPRNumber, currentPRHeadRef, err = prSelectorForCurrentBranch(baseRepo, currentBranch, remotes)
+		currentPRNumber, currentPRHeadRef, err = prSelectorForCurrentBranch(opts.GitClient, baseRepo, currentBranch, remotes)
 		if err != nil {
 			return fmt.Errorf("could not query for pull request for current branch: %w", err)
 		}
 	}
 
 	options := requestOptions{
-		Username:  "@me",
-		CurrentPR: currentPRNumber,
-		HeadRef:   currentPRHeadRef,
+		Username:       "@me",
+		CurrentPR:      currentPRNumber,
+		HeadRef:        currentPRHeadRef,
+		ConflictStatus: opts.ConflictStatus,
 	}
 	if opts.Exporter != nil {
 		options.Fields = opts.Exporter.Fields()
 	}
+
 	prPayload, err := pullRequestStatus(httpClient, baseRepo, options)
 	if err != nil {
 		return err
@@ -161,9 +168,9 @@ func statusRun(opts *StatusOptions) error {
 	return nil
 }
 
-func prSelectorForCurrentBranch(baseRepo ghrepo.Interface, prHeadRef string, rem context.Remotes) (prNumber int, selector string, err error) {
+func prSelectorForCurrentBranch(gitClient *git.Client, baseRepo ghrepo.Interface, prHeadRef string, rem ghContext.Remotes) (prNumber int, selector string, err error) {
 	selector = prHeadRef
-	branchConfig := git.ReadBranchConfig(prHeadRef)
+	branchConfig := gitClient.ReadBranchConfig(context.Background(), prHeadRef)
 
 	// the branch is configured to merge a special PR head ref
 	prHeadRE := regexp.MustCompile(`^refs/pull/(\d+)/head$`)
@@ -217,7 +224,7 @@ func printPrs(io *iostreams.IOStreams, totalCount int, prs ...api.PullRequest) {
 
 		prStateColorFunc := cs.ColorFromString(shared.ColorForPRState(pr))
 
-		fmt.Fprintf(w, "  %s  %s %s", prStateColorFunc(prNumber), text.Truncate(50, text.ReplaceExcessiveWhitespace(pr.Title)), cs.Cyan("["+pr.HeadLabel()+"]"))
+		fmt.Fprintf(w, "  %s  %s %s", prStateColorFunc(prNumber), text.Truncate(50, text.RemoveExcessiveWhitespace(pr.Title)), cs.Cyan("["+pr.HeadLabel()+"]"))
 
 		checks := pr.ChecksStatus()
 		reviews := pr.ReviewStatus()
@@ -230,18 +237,7 @@ func printPrs(io *iostreams.IOStreams, totalCount int, prs ...api.PullRequest) {
 			}
 
 			if checks.Total > 0 {
-				var summary string
-				if checks.Failing > 0 {
-					if checks.Failing == checks.Total {
-						summary = cs.Red("× All checks failing")
-					} else {
-						summary = cs.Redf("× %d/%d checks failing", checks.Failing, checks.Total)
-					}
-				} else if checks.Pending > 0 {
-					summary = cs.Yellow("- Checks pending")
-				} else if checks.Passing == checks.Total {
-					summary = cs.Green("✓ Checks passing")
-				}
+				summary := shared.PrCheckStatusSummaryWithColor(cs, checks)
 				fmt.Fprint(w, summary)
 			}
 
@@ -264,6 +260,17 @@ func printPrs(io *iostreams.IOStreams, totalCount int, prs ...api.PullRequest) {
 				fmt.Fprint(w, cs.Green(fmt.Sprintf("✓ %s Approved", s)))
 			}
 
+			if pr.Mergeable == "MERGEABLE" {
+				// prefer "No merge conflicts" to "Mergeable" as there is more to mergeability
+				// than the git status. Missing or failing required checks prevent merging
+				// even though a PR is technically mergeable, which is often a source of confusion.
+				fmt.Fprintf(w, " %s", cs.Green("✓ No merge conflicts"))
+			} else if pr.Mergeable == "CONFLICTING" {
+				fmt.Fprintf(w, " %s", cs.Red("× Merge conflicts"))
+			} else if pr.Mergeable == "UNKNOWN" {
+				fmt.Fprintf(w, " %s", cs.Yellow("! Merge conflict status unknown"))
+			}
+
 			if pr.BaseRef.BranchProtectionRule.RequiresStrictStatusChecks {
 				switch pr.MergeStateStatus {
 				case "BEHIND":
