@@ -5,25 +5,22 @@ import (
 	"sort"
 	"strconv"
 	"strings"
+	"time"
 
 	"github.com/MakeNowJust/heredoc"
 	"github.com/cli/cli/v2/api"
+	"github.com/cli/cli/v2/internal/browser"
+	"github.com/cli/cli/v2/internal/text"
 	"github.com/cli/cli/v2/pkg/cmd/pr/shared"
 	"github.com/cli/cli/v2/pkg/cmdutil"
 	"github.com/cli/cli/v2/pkg/iostreams"
 	"github.com/cli/cli/v2/pkg/markdown"
-	"github.com/cli/cli/v2/pkg/text"
-	"github.com/cli/cli/v2/utils"
 	"github.com/spf13/cobra"
 )
 
-type browser interface {
-	Browse(string) error
-}
-
 type ViewOptions struct {
 	IO      *iostreams.IOStreams
-	Browser browser
+	Browser browser.Browser
 
 	Finder   shared.PRFinder
 	Exporter cmdutil.Exporter
@@ -31,12 +28,15 @@ type ViewOptions struct {
 	SelectorArg string
 	BrowserMode bool
 	Comments    bool
+
+	Now func() time.Time
 }
 
 func NewCmdView(f *cmdutil.Factory, runF func(*ViewOptions) error) *cobra.Command {
 	opts := &ViewOptions{
 		IO:      f.IOStreams,
 		Browser: f.Browser,
+		Now:     time.Now,
 	}
 
 	cmd := &cobra.Command{
@@ -81,7 +81,7 @@ var defaultFields = []string{
 	"isDraft", "maintainerCanModify", "mergeable", "additions", "deletions", "commitsCount",
 	"baseRefName", "headRefName", "headRepositoryOwner", "headRepository", "isCrossRepository",
 	"reviewRequests", "reviews", "assignees", "labels", "projectCards", "milestone",
-	"comments", "reactionGroups",
+	"comments", "reactionGroups", "createdAt", "statusCheckRollup",
 }
 
 func viewRun(opts *ViewOptions) error {
@@ -104,7 +104,7 @@ func viewRun(opts *ViewOptions) error {
 	if opts.BrowserMode {
 		openURL := pr.URL
 		if connectedToTerminal {
-			fmt.Fprintf(opts.IO.ErrOut, "Opening %s in your browser.\n", utils.DisplayURL(openURL))
+			fmt.Fprintf(opts.IO.ErrOut, "Opening %s in your browser.\n", text.DisplayURL(openURL))
 		}
 		return opts.Browser.Browse(openURL)
 	}
@@ -171,16 +171,30 @@ func printHumanPrPreview(opts *ViewOptions, pr *api.PullRequest) error {
 	// Header (Title and State)
 	fmt.Fprintf(out, "%s #%d\n", cs.Bold(pr.Title), pr.Number)
 	fmt.Fprintf(out,
-		"%s • %s wants to merge %s into %s from %s • %s %s \n",
+		"%s • %s wants to merge %s into %s from %s • %s\n",
 		shared.StateTitleWithColor(cs, *pr),
 		pr.Author.Login,
-		utils.Pluralize(pr.Commits.TotalCount, "commit"),
+		text.Pluralize(pr.Commits.TotalCount, "commit"),
 		pr.BaseRefName,
 		pr.HeadRefName,
+		text.FuzzyAgo(opts.Now(), pr.CreatedAt),
+	)
+
+	// added/removed
+	fmt.Fprintf(out,
+		"%s %s",
 		cs.Green("+"+strconv.Itoa(pr.Additions)),
 		cs.Red("-"+strconv.Itoa(pr.Deletions)),
 	)
 
+	// checks
+	checks := pr.ChecksStatus()
+	if summary := shared.PrCheckStatusSummaryWithColor(cs, checks); summary != "" {
+		fmt.Fprintf(out, " • %s\n", summary)
+	} else {
+		fmt.Fprintln(out)
+	}
+
 	// Reactions
 	if reactions := shared.ReactionGroupList(pr.ReactionGroups); reactions != "" {
 		fmt.Fprint(out, reactions)
@@ -215,7 +229,9 @@ func printHumanPrPreview(opts *ViewOptions, pr *api.PullRequest) error {
 	if pr.Body == "" {
 		md = fmt.Sprintf("\n  %s\n\n", cs.Gray("No description provided"))
 	} else {
-		md, err = markdown.Render(pr.Body, markdown.WithIO(opts.IO))
+		md, err = markdown.Render(pr.Body,
+			markdown.WithTheme(opts.IO.TerminalTheme()),
+			markdown.WithWrap(opts.IO.TerminalWidth()))
 		if err != nil {
 			return err
 		}
