@@ -47,16 +47,20 @@ With no argument, archives the current repository.`),
 			}
 
 			if !opts.Confirmed && !opts.IO.CanPrompt() {
-				return cmdutil.FlagErrorf("--confirm required when not running interactively")
+				return cmdutil.FlagErrorf("--yes required when not running interactively")
 			}
+
 			if runF != nil {
 				return runF(opts)
 			}
+
 			return archiveRun(opts)
 		},
 	}
 
-	cmd.Flags().BoolVarP(&opts.Confirmed, "confirm", "y", false, "Skip the confirmation prompt")
+	cmd.Flags().BoolVar(&opts.Confirmed, "confirm", false, "Skip the confirmation prompt")
+	_ = cmd.Flags().MarkDeprecated("confirm", "use `--yes` instead")
+	cmd.Flags().BoolVarP(&opts.Confirmed, "yes", "y", false, "Skip the confirmation prompt")
 	return cmd
 }
 
@@ -115,6 +119,7 @@ func archiveRun(opts *ArchiveOptions) error {
 			Message: fmt.Sprintf("Archive %s?", fullName),
 			Default: false,
 		}
+		//nolint:staticcheck // SA1019: prompt.SurveyAskOne is deprecated: use Prompter
 		err = prompt.SurveyAskOne(p, &opts.Confirmed)
 		if err != nil {
 			return fmt.Errorf("failed to prompt: %w", err)
