@@ -16,6 +16,7 @@ import (
 	fd "github.com/cli/cli/v2/internal/featuredetection"
 	"github.com/cli/cli/v2/internal/ghinstance"
 	"github.com/cli/cli/v2/internal/ghrepo"
+	"github.com/cli/cli/v2/internal/prompter"
 	"github.com/cli/cli/v2/pkg/cmdutil"
 	"github.com/cli/cli/v2/pkg/iostreams"
 	"github.com/cli/cli/v2/pkg/prompt"
@@ -52,6 +53,7 @@ type EditOptions struct {
 	RemoveTopics    []string
 	InteractiveMode bool
 	Detector        fd.Detector
+	Prompter        prompter.Prompter
 	// Cache of current repo topics to avoid retrieving them
 	// in multiple flows.
 	topicsCache []string
@@ -78,7 +80,8 @@ type EditRepositoryInput struct {
 
 func NewCmdEdit(f *cmdutil.Factory, runF func(options *EditOptions) error) *cobra.Command {
 	opts := &EditOptions{
-		IO: f.IOStreams,
+		IO:       f.IOStreams,
+		Prompter: f.Prompter,
 	}
 
 	cmd := &cobra.Command{
@@ -95,6 +98,8 @@ func NewCmdEdit(f *cmdutil.Factory, runF func(options *EditOptions) error) *cobr
 			Edit repository settings.
 
 			To toggle a setting off, use the %[1]s--flag=false%[1]s syntax.
+
+			Note that changing repository visibility to private will cause loss of stars and watchers.
 		`, "`"),
 		Args: cobra.MaximumNArgs(1),
 		Example: heredoc.Doc(`
@@ -192,7 +197,9 @@ func editRun(ctx context.Context, opts *EditOptions) error {
 			"mergeCommitAllowed",
 			"rebaseMergeAllowed",
 			"repositoryTopics",
+			"stargazerCount",
 			"squashMergeAllowed",
+			"watchers",
 		}
 		if repoFeatures.VisibilityField {
 			fieldsToRetrieve = append(fieldsToRetrieve, "visibility")
@@ -404,15 +411,24 @@ func interactiveRepoEdit(opts *EditOptions, r *api.Repository) error {
 			}
 		case optionVisibility:
 			opts.Edits.Visibility = &r.Visibility
-			//nolint:staticcheck // SA1019: prompt.SurveyAskOne is deprecated: use Prompter
-			err = prompt.SurveyAskOne(&survey.Select{
-				Message: "Visibility",
-				Options: []string{"public", "private", "internal"},
-				Default: strings.ToLower(r.Visibility),
-			}, opts.Edits.Visibility)
+			visibilityOptions := []string{"public", "private", "internal"}
+			selected, err := opts.Prompter.Select("Visibility", strings.ToLower(r.Visibility), visibilityOptions)
 			if err != nil {
 				return err
 			}
+			confirmed := true
+			if visibilityOptions[selected] == "private" &&
+				(r.StargazerCount > 0 || r.Watchers.TotalCount > 0) {
+				cs := opts.IO.ColorScheme()
+				fmt.Fprintf(opts.IO.ErrOut, "%s Changing the repository visibility to private will cause permanent loss of stars and watchers.\n", cs.WarningIcon())
+				confirmed, err = opts.Prompter.Confirm("Do you want to change visibility to private?", false)
+				if err != nil {
+					return err
+				}
+			}
+			if confirmed {
+				opts.Edits.Visibility = &visibilityOptions[selected]
+			}
 		case optionMergeOptions:
 			var defaultMergeOptions []string
 			var selectedMergeOptions []string
