@@ -1,13 +1,14 @@
 package rename
 
 import (
+	"context"
 	"fmt"
 	"net/http"
 
 	"github.com/AlecAivazis/survey/v2"
 	"github.com/MakeNowJust/heredoc"
 	"github.com/cli/cli/v2/api"
-	"github.com/cli/cli/v2/context"
+	ghContext "github.com/cli/cli/v2/context"
 	"github.com/cli/cli/v2/git"
 	"github.com/cli/cli/v2/internal/config"
 	"github.com/cli/cli/v2/internal/ghrepo"
@@ -19,10 +20,11 @@ import (
 
 type RenameOptions struct {
 	HttpClient      func() (*http.Client, error)
+	GitClient       *git.Client
 	IO              *iostreams.IOStreams
 	Config          func() (config.Config, error)
 	BaseRepo        func() (ghrepo.Interface, error)
-	Remotes         func() (context.Remotes, error)
+	Remotes         func() (ghContext.Remotes, error)
 	DoConfirm       bool
 	HasRepoOverride bool
 	newRepoSelector string
@@ -32,6 +34,7 @@ func NewCmdRename(f *cmdutil.Factory, runf func(*RenameOptions) error) *cobra.Co
 	opts := &RenameOptions{
 		IO:         f.IOStreams,
 		HttpClient: f.HttpClient,
+		GitClient:  f.GitClient,
 		Remotes:    f.Remotes,
 		Config:     f.Config,
 	}
@@ -57,7 +60,7 @@ func NewCmdRename(f *cmdutil.Factory, runf func(*RenameOptions) error) *cobra.Co
 
 			if len(args) == 1 && !confirm && !opts.HasRepoOverride {
 				if !opts.IO.CanPrompt() {
-					return cmdutil.FlagErrorf("--confirm required when passing a single argument")
+					return cmdutil.FlagErrorf("--yes required when passing a single argument")
 				}
 				opts.DoConfirm = true
 			}
@@ -65,12 +68,15 @@ func NewCmdRename(f *cmdutil.Factory, runf func(*RenameOptions) error) *cobra.Co
 			if runf != nil {
 				return runf(opts)
 			}
+
 			return renameRun(opts)
 		},
 	}
 
 	cmdutil.EnableRepoOverride(cmd, f)
-	cmd.Flags().BoolVarP(&confirm, "confirm", "y", false, "skip confirmation prompt")
+	cmd.Flags().BoolVar(&confirm, "confirm", false, "Skip confirmation prompt")
+	_ = cmd.Flags().MarkDeprecated("confirm", "use `--yes` instead")
+	cmd.Flags().BoolVarP(&confirm, "yes", "y", false, "Skip the confirmation prompt")
 
 	return cmd
 }
@@ -145,7 +151,7 @@ func renameRun(opts *RenameOptions) error {
 	return nil
 }
 
-func updateRemote(repo ghrepo.Interface, renamed ghrepo.Interface, opts *RenameOptions) (*context.Remote, error) {
+func updateRemote(repo ghrepo.Interface, renamed ghrepo.Interface, opts *RenameOptions) (*ghContext.Remote, error) {
 	cfg, err := opts.Config()
 	if err != nil {
 		return nil, err
@@ -167,6 +173,7 @@ func updateRemote(repo ghrepo.Interface, renamed ghrepo.Interface, opts *RenameO
 	}
 
 	remoteURL := ghrepo.FormatRemoteURL(renamed, protocol)
-	err = git.UpdateRemoteURL(remote.Name, remoteURL)
+	err = opts.GitClient.UpdateRemoteURL(context.Background(), remote.Name, remoteURL)
+
 	return remote, err
 }
