@@ -35,7 +35,7 @@ func TestNewCmdRename(t *testing.T) {
 		},
 		{
 			name:  "one argument no tty confirmed",
-			input: "REPO --confirm",
+			input: "REPO --yes",
 			output: RenameOptions{
 				newRepoSelector: "REPO",
 			},
@@ -43,12 +43,12 @@ func TestNewCmdRename(t *testing.T) {
 		{
 			name:    "one argument no tty",
 			input:   "REPO",
-			errMsg:  "--confirm required when passing a single argument",
+			errMsg:  "--yes required when passing a single argument",
 			wantErr: true,
 		},
 		{
 			name:  "one argument tty confirmed",
-			input: "REPO --confirm",
+			input: "REPO --yes",
 			tty:   true,
 			output: RenameOptions{
 				newRepoSelector: "REPO",
@@ -259,6 +259,8 @@ func TestRenameRun(t *testing.T) {
 		ios.SetStdoutTTY(tt.tty)
 		tt.opts.IO = ios
 
+		tt.opts.GitClient = &git.Client{GitPath: "some/path/git"}
+
 		t.Run(tt.name, func(t *testing.T) {
 			defer reg.Verify(t)
 			err := renameRun(&tt.opts)
