@@ -13,6 +13,7 @@ import (
 	gardenCmd "github.com/cli/cli/v2/pkg/cmd/repo/garden"
 	repoListCmd "github.com/cli/cli/v2/pkg/cmd/repo/list"
 	repoRenameCmd "github.com/cli/cli/v2/pkg/cmd/repo/rename"
+	repoDefaultCmd "github.com/cli/cli/v2/pkg/cmd/repo/setdefault"
 	repoSyncCmd "github.com/cli/cli/v2/pkg/cmd/repo/sync"
 	repoViewCmd "github.com/cli/cli/v2/pkg/cmd/repo/view"
 	"github.com/cli/cli/v2/pkg/cmdutil"
@@ -30,28 +31,34 @@ func NewCmdRepo(f *cmdutil.Factory) *cobra.Command {
 			$ gh repo view --web
 		`),
 		Annotations: map[string]string{
-			"IsCore": "true",
 			"help:arguments": heredoc.Doc(`
 				A repository can be supplied as an argument in any of the following formats:
 				- "OWNER/REPO"
 				- by URL, e.g. "https://github.com/OWNER/REPO"
 			`),
 		},
+		GroupID: "core",
 	}
 
-	cmd.AddCommand(repoViewCmd.NewCmdView(f, nil))
-	cmd.AddCommand(repoForkCmd.NewCmdFork(f, nil))
-	cmd.AddCommand(repoCloneCmd.NewCmdClone(f, nil))
-	cmd.AddCommand(repoCreateCmd.NewCmdCreate(f, nil))
-	cmd.AddCommand(repoEditCmd.NewCmdEdit(f, nil))
-	cmd.AddCommand(repoListCmd.NewCmdList(f, nil))
-	cmd.AddCommand(repoSyncCmd.NewCmdSync(f, nil))
-	cmd.AddCommand(creditsCmd.NewCmdRepoCredits(f, nil))
-	cmd.AddCommand(gardenCmd.NewCmdGarden(f, nil))
-	cmd.AddCommand(deployKeyCmd.NewCmdDeployKey(f))
-	cmd.AddCommand(repoRenameCmd.NewCmdRename(f, nil))
-	cmd.AddCommand(repoDeleteCmd.NewCmdDelete(f, nil))
-	cmd.AddCommand(repoArchiveCmd.NewCmdArchive(f, nil))
+	cmdutil.AddGroup(cmd, "General commands",
+		repoListCmd.NewCmdList(f, nil),
+		repoCreateCmd.NewCmdCreate(f, nil),
+	)
+
+	cmdutil.AddGroup(cmd, "Targeted commands",
+		repoViewCmd.NewCmdView(f, nil),
+		repoCloneCmd.NewCmdClone(f, nil),
+		repoForkCmd.NewCmdFork(f, nil),
+		repoDefaultCmd.NewCmdSetDefault(f, nil),
+		repoSyncCmd.NewCmdSync(f, nil),
+		repoEditCmd.NewCmdEdit(f, nil),
+		deployKeyCmd.NewCmdDeployKey(f),
+		repoRenameCmd.NewCmdRename(f, nil),
+		repoArchiveCmd.NewCmdArchive(f, nil),
+		repoDeleteCmd.NewCmdDelete(f, nil),
+		creditsCmd.NewCmdRepoCredits(f, nil),
+		gardenCmd.NewCmdGarden(f, nil),
+	)
 
 	return cmd
 }
