@@ -19,7 +19,9 @@ func referenceHelpFn(io *iostreams.IOStreams) func(*cobra.Command, []string) {
 			wrapWidth = io.TerminalWidth()
 		}
 
-		md, err := markdown.Render(cmd.Long, markdown.WithIO(io), markdown.WithWrap(wrapWidth))
+		md, err := markdown.Render(cmd.Long,
+			markdown.WithTheme(io.TerminalTheme()),
+			markdown.WithWrap(wrapWidth))
 		if err != nil {
 			fmt.Fprintln(io.ErrOut, err)
 			return
