@@ -13,12 +13,10 @@ import (
 
 func NewCmdRun(f *cmdutil.Factory) *cobra.Command {
 	cmd := &cobra.Command{
-		Use:   "run <command>",
-		Short: "View details about workflow runs",
-		Long:  "List, view, and watch recent workflow runs from GitHub Actions.",
-		Annotations: map[string]string{
-			"IsActions": "true",
-		},
+		Use:     "run <command>",
+		Short:   "View details about workflow runs",
+		Long:    "List, view, and watch recent workflow runs from GitHub Actions.",
+		GroupID: "actions",
 	}
 	cmdutil.EnableRepoOverride(cmd, f)
 
