@@ -2,8 +2,8 @@ package secret
 
 import (
 	"github.com/MakeNowJust/heredoc"
+	cmdDelete "github.com/cli/cli/v2/pkg/cmd/secret/delete"
 	cmdList "github.com/cli/cli/v2/pkg/cmd/secret/list"
-	cmdRemove "github.com/cli/cli/v2/pkg/cmd/secret/remove"
 	cmdSet "github.com/cli/cli/v2/pkg/cmd/secret/set"
 	"github.com/cli/cli/v2/pkg/cmdutil"
 	"github.com/spf13/cobra"
@@ -14,9 +14,10 @@ func NewCmdSecret(f *cmdutil.Factory) *cobra.Command {
 		Use:   "secret <command>",
 		Short: "Manage GitHub secrets",
 		Long: heredoc.Doc(`
-			Secrets can be set at the repository, environment, or organization level for use in
-			GitHub Actions. User secrets can be set for use in GitHub Codespaces.
-			Run "gh help secret set" to learn how to get started.
+			Secrets can be set at the repository, or organization level for use in
+			GitHub Actions or Dependabot. User, organization, and repository secrets can be set for
+			use in GitHub Codespaces. Environment secrets can be set for use in
+			GitHub Actions. Run "gh help secret set" to learn how to get started.
 `),
 	}
 
@@ -24,7 +25,7 @@ func NewCmdSecret(f *cmdutil.Factory) *cobra.Command {
 
 	cmd.AddCommand(cmdList.NewCmdList(f, nil))
 	cmd.AddCommand(cmdSet.NewCmdSet(f, nil))
-	cmd.AddCommand(cmdRemove.NewCmdRemove(f, nil))
+	cmd.AddCommand(cmdDelete.NewCmdDelete(f, nil))
 
 	return cmd
 }
