@@ -7,6 +7,7 @@ import (
 	"testing"
 
 	"github.com/MakeNowJust/heredoc"
+	"github.com/cli/cli/v2/internal/browser"
 	"github.com/cli/cli/v2/internal/ghrepo"
 	runShared "github.com/cli/cli/v2/pkg/cmd/run/shared"
 	"github.com/cli/cli/v2/pkg/cmd/workflow/shared"
@@ -175,10 +176,10 @@ func TestViewRun(t *testing.T) {
 
 		Total runs 10
 		Recent runs
-		X  cool commit  timed out    trunk  push  1
-		*  cool commit  in progress  trunk  push  2
-		✓  cool commit  successful   trunk  push  3
-		X  cool commit  cancelled    trunk  push  4
+		X  cool commit  a workflow  trunk  push  1
+		*  cool commit  a workflow  trunk  push  2
+		✓  cool commit  a workflow  trunk  push  3
+		X  cool commit  a workflow  trunk  push  4
 
 		To see more runs for this workflow, try: gh run list --workflow flow.yml
 		To see the YAML for this workflow, try: gh workflow view flow.yml --yaml
@@ -412,7 +413,7 @@ func TestViewRun(t *testing.T) {
 			return ghrepo.FromFullName("OWNER/REPO")
 		}
 
-		browser := &cmdutil.TestBrowser{}
+		browser := &browser.Stub{}
 		tt.opts.Browser = browser
 
 		t.Run(tt.name, func(t *testing.T) {
