@@ -19,18 +19,21 @@ type Extension interface {
 	Name() string // Extension Name without gh-
 	Path() string // Path to executable
 	URL() string
-	IsLocal() bool
+	CurrentVersion() string
+	IsPinned() bool
 	UpdateAvailable() bool
 	IsBinary() bool
+	IsLocal() bool
 }
 
 //go:generate moq -rm -out manager_mock.go . ExtensionManager
 type ExtensionManager interface {
-	List(includeMetadata bool) []Extension
-	Install(ghrepo.Interface) error
+	List() []Extension
+	Install(ghrepo.Interface, string) error
 	InstallLocal(dir string) error
 	Upgrade(name string, force bool) error
 	Remove(name string) error
 	Dispatch(args []string, stdin io.Reader, stdout, stderr io.Writer) (bool, error)
 	Create(name string, tmplType ExtTemplateType) error
+	EnableDryRunMode()
 }
